﻿using Microsoft.AspNetCore.Mvc;
using Microsoft.AspNetCore.Mvc.Filters;
using Microsoft.Extensions.Logging;
using Performance.DtoModels;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;

namespace Performance.Api
{
    public class ActionsFilter : IAsyncActionFilter
    {
        private readonly ILoggerFactory factory;

        public ActionsFilter(ILoggerFactory factory)
        {
            this.factory = factory;
        }

        public async Task OnActionExecutionAsync(ActionExecutingContext context, ActionExecutionDelegate next)
        {
            var logger = factory.CreateLogger<ActionsFilter>();
            logger.LogWarning($"action filter is executing new ,context.modelstate:{context.ModelState.IsValid}");

            if (!context.ModelState.IsValid)
            {
                string errorMessage = string.Join(",", context.ModelState.Values.Select(t => t?.Errors?.FirstOrDefault()?.ErrorMessage));
                var response = new ApiResponse(ResponseType.ParameterError, "参数错误", errorMessage);
                context.Result = new ObjectResult(response);
                return;
            }

            var executedContext = await next();
            logger.LogWarning($"action filter is executed now,executedContext controller:{executedContext.Controller.ToString()}");
        }
    }
}
